@@ -21,7 +21,17 @@ from pipeline.workspace_manager import WorkspaceManager
 from pipeline import helpers
 from pipeline.decorators import log_function_call
 from pipeline.time_manager import TimeManager
-from pipeline.security_and_config import get_configurable_default_plant_name, _get_credential_with_prompt, _get_base_url_config_with_prompt, _get_config_with_prompt, get_configurable_idcs_list, get_temporary_input
+from pipeline.security_and_config import SecurityAndConfig, get_base_url_config_with_prompt
+#from pipeline.variable_clarity_grok import Redundancy
+from pipeline.variable_clarity import Redundancy
+
+#get_configurable_default_plant_name, 
+#_get_credential_with_prompt, 
+# 
+#_get_config_with_prompt, 
+#get_configurable_idcs_list, 
+#get_temporary_input
+
 
 
 if on_windows():
@@ -51,7 +61,38 @@ class EdsLoginException(Exception):
         super().__init__(self.message)
 
 class EdsClient:
+    def __init__(self):
+        pass
 
+    # --- Context Management (Pattern 2) ---
+    def __enter__(self):
+        """Called upon entering the 'with' block."""
+        return self
+    
+    def __exit__(self, exc_type, exc_val, exc_tb):
+        """Called upon exiting the 'with' block (for cleanup)."""
+        
+        # 1. Close REST Session
+        if hasattr(self, "session"):
+            print(f"[{self.plant_name}] Closing REST session.")
+            self.session.close()
+            
+        # 2. Logout from SOAP (if login was performed)
+        if self.authstring:
+            print(f"[{self.plant_name}] Attempting SOAP logout...")
+            try:
+                # We need a SOAP client instance to perform the logout
+                if self.soapclient is None:
+                    # Initialize just to logout, if not done already
+                    self.soapclient = SudsClient(self.soap_url)
+                self.soapclient.service.logout(self.authstring)
+                print(f"[{self.plant_name}] Logout successful.")
+            except Exception as e:
+                print(f"[{self.plant_name}] Error during SOAP logout: {e}")
+                
+        # Return False to propagate exceptions, or True to suppress them
+        return False 
+    
     @staticmethod
     def login_to_session(api_url, username, password, timeout=10):
         session = requests.Session()
@@ -566,52 +607,102 @@ class EdsClient:
         logger.info(f"Successfully retrieved data for {len(point)} point(s)")
         return results
     
+    @log_function_call(level=logging.DEBUG)    
+    @staticmethod
+    def load_historic_data(session, filter_iess, starttime, endtime, step_seconds):    
+        """
+        Retrieves historic time series data for a list of points (IESS)
+        within a specified time range and step interval using the EDS API.
+
+        This function converts the start and end times to Unix timestamps,
+        creates a tabular trend request, waits for its execution, and
+        then retrieves the results.
+
+        Args:
+            session (EdsSession): The authenticated EDS API session object.
+            filter_iess (list[str]): A list of point IDs (IESS) for which
+                                    to retrieve data.
+            starttime (str or int): The start time for the data request.
+                                    Can be a datetime string or a Unix timestamp.
+            endtime (str or int): The end time for the data request.
+                                Can be a datetime string or a Unix timestamp.
+            step_seconds (int): The aggregation interval (step size) in seconds.
+
+        Returns:
+            list[dict] or list: A list of dictionaries containing the historic
+                                data results (tabular trend), or an empty list
+                                if the request creation failed.
+        """
+
+        starttime = TimeManager(starttime).as_unix()
+        endtime = TimeManager(endtime).as_unix() 
+        logger.info(f"starttime = {starttime}")
+        logger.info(f"endtime = {endtime}")
+
+
+        point_list = filter_iess
+        api_url = str(session.base_url) 
+        request_id = EdsClient.create_tabular_request(session, api_url, starttime, endtime, points=point_list, step_seconds=step_seconds)
+        if not request_id:
+            logger.warning(f"Could not create tabular request for points: {point_list}")
+            return []  # or None, depending on how you want the CLI to behave
+        EdsClient.wait_for_request_execution_session(session, api_url, request_id)
+        results = EdsClient.get_tabular_trend(session, request_id, point_list)
+        logger.debug(f"len(results) = {len(results)}")
+        return results
+
     @staticmethod
     def get_service_name(plant_name: str|None = None) -> str | None:
         """
         Describe the standardized string describing the service name that will be known to the system keyring for secure credentials.
         """
         if plant_name is None:
-            plant_name = get_configurable_default_plant_name()
+            plant_name = SecurityAndConfig.get_configurable_default_plant_name()
         if plant_name is None:
             return None
         service_name = f"pipeline-eds-api-{plant_name}" 
         return service_name
     
     @classmethod
+    @Redundancy.set_on_return_hint(recipient=None,attribute_name="tabular_data")
     def soap_api_iess_request_tabular(cls, plant_name: str | None= None, idcs: list[str] | None = None):
+        
+        tabular_data = None
         soapclient = None
         authstring = None
+        
         use_default_idcs = True
         if plant_name is None:
-            plant_name = get_configurable_default_plant_name()
+            plant_name = SecurityAndConfig.get_configurable_default_plant_name()
         print(f"plant_name = {plant_name}")
         service_name = EdsClient.get_service_name(plant_name = plant_name) # for secure credentials
     
         if idcs is None:
             if use_default_idcs:
-                idcs = get_configurable_idcs_list(plant_name)
+                idcs = SecurityAndConfig.get_configurable_idcs_list(plant_name)
             else:
-                idcs = get_temporary_input()
+                idcs = SecurityAndConfig.get_temporary_input()
         
-        base_url = _get_base_url_config_with_prompt(service_name = f"{plant_name}_eds_base_url", prompt_message=f"Enter {plant_name} EDS base url (e.g., http://000.00.0.000, or just 000.00.0.000)")
-        eds_soap_api_port = _get_credential_with_prompt(service_name = f"{plant_name}_eds_soap_api_port", prompt_message=f"Enter {plant_name} EDS SOAP API port (e.g., 43080)")
-        eds_soap_api_sub_path = _get_credential_with_prompt(f"{plant_name}_eds_soap_api_sub_path", f"Enter {plant_name} EDS SOAP API WSDL PATH (e.g., 'eds.wsdl')", default = cls.access_database_files_locally)
-        username = _get_credential_with_prompt(service_name, "username", f"Enter your EDS API username for {plant_name} (e.g. admin)", hide_password=False)
-        password = _get_credential_with_prompt(service_name, "password", f"Enter your EDS API password for {plant_name} (e.g. '')")
-        idcs_to_iess_suffix = _get_config_with_prompt(f"{plant_name}_eds_api_iess_suffix", f"Enter iess suffix for {plant_name} (e.g., .UNIT0@NET0)")
+        base_url = get_base_url_config_with_prompt(service_name = f"{plant_name}_eds_base_url", prompt_message=f"Enter {plant_name} EDS base url (e.g., http://000.00.0.000, or just 000.00.0.000)")
+        eds_soap_api_port = SecurityAndConfig.get_config_with_prompt(config_key = f"{plant_name}_eds_soap_api_port", prompt_message=f"Enter {plant_name} EDS SOAP API port (e.g., 43080)")
+        eds_soap_api_sub_path = SecurityAndConfig.get_config_with_prompt(config_key = f"{plant_name}_eds_soap_api_sub_path", prompt_message=f"Enter {plant_name} EDS SOAP API WSDL PATH (e.g., 'eds.wsdl')")
+        username = SecurityAndConfig.get_credential_with_prompt(service_name, "username", f"Enter your EDS API username for {plant_name} (e.g. admin)", hide=False)
+        password = SecurityAndConfig.get_credential_with_prompt(service_name, "password", f"Enter your EDS API password for {plant_name} (e.g. '')")
+        idcs_to_iess_suffix = SecurityAndConfig.get_config_with_prompt(f"{plant_name}_eds_api_iess_suffix", f"Enter iess suffix for {plant_name} (e.g., .UNIT0@NET0)")
         
         #session = EdsClient.login_to_session_with_api_credentials(api_credentials)
         
-        eds_soap_api_url = EdsClient.get_soap_api_url(base_url = base_url, eds_soap_api_port = eds_soap_api_port, eds_soap_api_sub_path = eds_soap_api_sub_path)
+        eds_soap_api_url = EdsClient.get_soap_api_url(base_url = base_url, 
+                                                      eds_soap_api_port = eds_soap_api_port, 
+                                                      eds_soap_api_sub_path = eds_soap_api_sub_path)
         if eds_soap_api_url is None:
             logging.info("Not enough information provided to build: eds_soap_api_url.")
             logging.info("Please rerun your last command or try something else.")
             sys.exit()
         try:
             # 1. Create the SOAP client
-            print(f"Attempting to connect to WSDL at: {soap_api_url}")
-            soapclient = SudsClient(soap_api_url)
+            print(f"Attempting to connect to WSDL at: {eds_soap_api_url}")
+            soapclient = SudsClient(eds_soap_api_url)
             print("SOAP client created successfully.")
             # You can uncomment the line below to see all available services
             # print(soapclient)
@@ -650,7 +741,7 @@ class EdsClient:
 
             # Example 4: Get a specific point by IESS name
             # We will use 'I-0300A.UNIT1@NET1' from your latest output
-            print("\n--- Example 4: Requesting point by IESS name ('I-0300A.UNIT1@NET1') ---")
+            print("\n--- Example 4: Requesting point by IESS name ('{}') ---")
             try:
                 # Create a PointFilter object
                 point_filter_iess = soapclient.factory.create('PointFilter')
@@ -753,7 +844,7 @@ class EdsClient:
 
 
         except Exception as e:
-            EdsClient.connection_error_message(e)
+            EdsClient.connection_error_message(e, url = eds_soap_api_url)
             
         finally:
             
@@ -770,12 +861,14 @@ class EdsClient:
             else:
                 print("\nSkipping logout (was not logged in).")
 
+        return tabular_data
+    
     @staticmethod
-    def connection_error_message(e)-> None:
+    def connection_error_message(e, url)-> None:
         print(f"\n--- AN ERROR OCCURRED ---")
         print(e)
         print("\nPlease check:")
-        print(f"1. Is the IP address {soap_api_url} correct and reachable?")
+        print(f"1. Is the IP address {url} correct and reachable?")
         print("2. Is the EDS server running?")
         print("3. Are your username and password correct?")
         return None
@@ -792,16 +885,17 @@ class EdsClient:
             plant_name = get_configurable_default_plant_name()
 
         service_name = EdsClient.get_service_name(plant_name = plant_name) # for secure credentials
-        base_url = _get_base_url_config_with_prompt(service_name=f"{plant_name}_eds_base_url", prompt_message=f"Enter {plant_name} EDS base url (e.g., http://000.00.0.000, or just 000.00.0.000)")
-        #eds_soap_api_port = _get_credential_with_prompt(f"{plant_name}_eds_soap_api_port", f"Enter {plant_name} EDS SOAP API port (e.g., 43080)")
-        #eds_soap_api_sub_path = _get_credential_with_prompt(f"{plant_name}_eds_soap_api_sub_path", f"Enter {plant_name} EDS SOAP API WSDL sub path (e.g., 'eds.wsdl')")
-        username = _get_credential_with_prompt(service_name, "username", f"Enter your EDS API username for {plant_name} (e.g. admin)", hide_password=False)
-        password = _get_credential_with_prompt(service_name, "password", f"Enter your EDS API password for {plant_name} (e.g. '')")
-        idcs_to_iess_suffix = _get_config_with_prompt(f"{plant_name}_eds_api_iess_suffix", f"Enter iess suffix for {plant_name} (e.g., .UNIT0@NET0)")
+        base_url = get_base_url_config_with_prompt(service_name=f"{plant_name}_eds_base_url", prompt_message=f"Enter {plant_name} EDS base url (e.g., http://000.00.0.000, or just 000.00.0.000)")
+        #eds_soap_api_port = SecurityAndConfig.get_credential_with_prompt(f"{plant_name}_eds_soap_api_port", f"Enter {plant_name} EDS SOAP API port (e.g., 43080)")
+        #eds_soap_api_sub_path = SecurityAndConfig.get_credential_with_prompt(f"{plant_name}_eds_soap_api_sub_path", f"Enter {plant_name} EDS SOAP API WSDL sub path (e.g., 'eds.wsdl')")
+        username = SecurityAndConfig.get_credential_with_prompt(service_name, "username", f"Enter your EDS API username for {plant_name} (e.g. admin)", hide=False)
+        password = SecurityAndConfig.get_credential_with_prompt(service_name, "password", f"Enter your EDS API password for {plant_name} (e.g. '')")
+        idcs_to_iess_suffix = SecurityAndConfig.get_config_with_prompt(f"{plant_name}_eds_api_iess_suffix", f"Enter iess suffix for {plant_name} (e.g., .UNIT0@NET0)")
         
         #session = EdsClient.login_to_session_with_api_credentials(api_credentials)
 
-        eds_soap_api_url = EdsClient.get_soap_api_url(base_url = base_url)
+        # Let API Port and the sub path be None, such that the defaults will be used.
+        eds_soap_api_url = EdsClient.get_soap_api_url(base_url = base_url, eds_soap_api_port = None, eds_soap_api_sub_path = None)
         if eds_soap_api_url is None:
             logging.info("Not enough information provided to build: eds_soap_api_url.")
             logging.info("Please rerun your last command or try something else.")
@@ -892,7 +986,7 @@ class EdsClient:
             # -----------------------------------------------
 
         except Exception as e:
-            EdsClient.connection_error_message(e)
+            EdsClient.connection_error_message(e, url = eds_soap_api_url)
             
         finally:
             # 4. Logout using the authstring
@@ -907,6 +1001,7 @@ class EdsClient:
                 print("\nSkipping logout (was not logged in).")    
     
     @classmethod
+    @Redundancy.set_on_return_hint(recipient=None,attribute_name="soap_api_url")
     def get_soap_api_url(cls,
                     base_url: str | None = None,
                     eds_soap_api_port: int | None = 43080, 
@@ -933,7 +1028,22 @@ class EdsClient:
         else:
             logging.info("EdsClient.get_soap_api_url() returns None due to incomplete information.")
             return None
-            
+        """
+        Stash soap_api_url as a class variable. 
+        Why? 
+        Because it makes it easy to reference and find.
+        And, it does not to be recalculated.
+        This function is a class method.
+        I am not converting it to an instance method for this one thing,
+        when the class is not expected to have multiple instances.
+        
+        Actually, thats an interesting question - 
+        Stiles and Maxon.
+        Two instantes of EdsCient.
+        Well then.
+        We just won't use the class attribute.
+        """
+         
         return soap_api_url
     
     @classmethod
@@ -1325,7 +1435,7 @@ def demo_eds_webplot_point_live():
                     logger.info(f"Live: {label} {round(av,2)} {un}")
             time.sleep(1)
     if False:
-        load_historic_data()
+        EdsClient.load_historic_data()
     collector_thread = Thread(target=collect_loop, daemon=True)
     collector_thread.start()
 
@@ -1333,26 +1443,7 @@ def demo_eds_webplot_point_live():
     #gui_flaskplotly_live.run_gui(data_buffer)
     gui_fastapi_plotly_live.run_gui(data_buffer)
 
-@log_function_call(level=logging.DEBUG)    
-def load_historic_data(session, filter_iess, starttime, endtime, step_seconds):    
-    
 
-    starttime = TimeManager(starttime).as_unix()
-    endtime = TimeManager(endtime).as_unix() 
-    logger.info(f"starttime = {starttime}")
-    logger.info(f"endtime = {endtime}")
-
-
-    point_list = filter_iess
-    api_url = str(session.base_url) 
-    request_id = EdsClient.create_tabular_request(session, api_url, starttime, endtime, points=point_list, step_seconds=step_seconds)
-    if not request_id:
-        logger.warning(f"Could not create tabular request for points: {point_list}")
-        return []  # or None, depending on how you want the CLI to behave
-    EdsClient.wait_for_request_execution_session(session, api_url, request_id)
-    results = EdsClient.get_tabular_trend(session, request_id, point_list)
-    logger.debug(f"len(results) = {len(results)}")
-    return results
     
                 
 
@@ -1519,13 +1610,14 @@ def demo_eds_ping():
     from pipeline.calls import call_ping
     workspace_manager, sessions = _demo_eds_start_session_CoM_WWTPs()
     session_maxson = sessions["Maxson"]
-
     response = call_ping(session_maxson.base_url)
 
 @log_function_call(level=logging.DEBUG)
 def demo_eds_soap_api_tabular():
-    #EdsClient.soap_api_iess_request_tabular(idcs = ['I-0300A','I-0301A'])
+
     EdsClient.soap_api_iess_request_tabular(plant_name = "Stiles",idcs = ['I-0300A','I-0301A'])
+    EdsClient.soap_api_iess_request_tabular(plant_name = "Maxson",idcs = ['FI8001','M310LI'])
+
 if __name__ == "__main__":
 
     '''
