@@ -6,12 +6,9 @@ from click import BadParameter
 import typer
 from pathlib import Path
 from importlib.metadata import version, PackageNotFoundError
-from requests.exceptions import Timeout
 import sys
-import pendulum
 import re
-from pyhabitat import on_termux, on_windows, is_pyz, is_elf, is_pipx, matplotlib_is_available_for_gui_plotting, edit_textfile
-
+import pyhabitat as ph
 
 try:
     import colorama # explicitly added so for the shiv build
@@ -24,11 +21,12 @@ except ImportError:
 
 from pipeline.time_manager import TimeManager
 from pipeline.create_sensors_db import get_db_connection, create_packaged_db, reset_user_db # get_user_db_path, ensure_user_db, 
-from pipeline.api.eds import demo_eds_webplot_point_live, EdsClient, load_historic_data, EdsLoginException, demo_eds_save_point_export
+from pipeline.api.eds import demo_eds_webplot_point_live, EdsClient, EdsLoginException, demo_eds_save_point_export
 from pipeline.security_and_config import get_eds_rest_api_credentials, get_external_api_credentials, get_eds_local_db_credentials, get_all_configured_urls, get_configurable_default_plant_name, init_security, CONFIG_PATH
 from pipeline.termux_setup import setup_termux_integration, cleanup_termux_integration
 from pipeline.windows_setup import setup_windows_integration, cleanup_windows_integration
 from pipeline import helpers
+from pipeline.interface import gui_eds
 from pipeline.plotbuffer import PlotBuffer
 from pipeline.version_info import  PIP_PACKAGE_NAME, PIPELINE_VERSION, __version__, get_package_version, get_package_name
 #from pipeline.helpers import setup_logging
@@ -39,9 +37,9 @@ from pipeline.version_info import  PIP_PACKAGE_NAME, PIPELINE_VERSION, __version
 # ensures the shortcut file is only created once in the Termux environment.
 #-- SUPPRESS with "False and" as of 0.3.53 - automaic installation on every run is invasive and is annyoring for troubleshooting, like if the user changes the .shortcut/filename
 #-- user may directly run 'install' command
-if False and on_termux():
+if False and ph.on_termux():
     setup_termux_integration()
-elif False and on_windows():
+elif False and ph.on_windows():
     setup_windows_integration()
 # --- end SETUP / INSTALL HOOK ---
 
@@ -70,6 +68,9 @@ def main(
     """
 
     if ctx.invoked_subcommand is None:
+        gui_eds.launch_fsg()
+        raise typer.Exit()
+    elif False:#ctx.invoked_subcommand is None:
         typer.echo(ctx.get_help())
         raise typer.Exit()
     
@@ -82,7 +83,15 @@ def main(
     # 3. Print the command
     typer.echo(f"command:\n{command_string}\n")
 
-
+@app.command(name="gui", help="Show the GUI and allow the user to see demo features.")
+def launch_gui_eds_trend(
+    force_web: bool = typer.Option(False, "--web", "-w", help="Force web-based GUI for data input, even when the FreeSimpleGUI local window would be available."),
+    ):
+    """
+    Allows GUI interaction with EDS Trend
+    """
+    gui_eds.main(force_web=force_web) 
+    
 @app.command()
 def list_sensors(
     db_path: str = None,
@@ -159,9 +168,10 @@ def trend(
     days: float = typer.Option(None, "--days", "-ds", help="Identify end time. Use any reasonable format, to be parsed automatically. If you must use spaces, use quotes."),
     plant_name: str = typer.Option(None, "--plantname", "-pn", help = "Provide the EDS ZD for your credentials."),
     print_csv: bool = typer.Option(False,"--print-csv","-p",help = "Print the CSV style for pasting into Excel."),
-    step_seconds: int = typer.Option(None, "--step-seconds", help="You can explicitly provide the delta between datapoints. If not, ~400 data points will be used, based on the nice_step() function."), 
+    seconds_between_points: int = typer.Option(None, "--seconds-between-points", "-sec", help="You can explicitly provide the delta between datapoints. If not, ~400 data points will be used, based on the nice_step() function."), 
+    datapoint_count: int = typer.Option(None, "--datapoint-count", "-dp", help="You can explicitly provide the number of datapoints. Default: ~400 data points will be used, based on the nice_step() function. If the --datapoints flag is provided, the --step-seconds flag will be ignored. "), 
     force_webplot: bool = typer.Option(False,"--webplot","-w",help = "Use a browser-based plot instead of local (matplotlib). Useful for remote servers without display."),
-    force_matplotlib: bool = typer.Option(False,"--matplotlib","-mpl",help="Forcr matplotlib to be used for plotting. This will not work if matplotlib is not available."),
+    force_matplotlib: bool = typer.Option(False,"--matplotlib","-mpl",help="Force matplotlib to be used for plotting. This will not work if matplotlib is not available."),
     default_idcs: bool = typer.Option(False, "--default-idcs", "-d", help="Use the default IDCS values for the configured plant name, instead of providing them as arguments.")
     ):
     """
@@ -231,9 +241,14 @@ def trend(
     dt_start, dt_finish = helpers.asses_time_range(starttime=starttime, endtime=endtime, days=days)
 
     # Should automatically choose time step granularity based on time length; map 
-    if step_seconds is None:
+    if datapoint_count is not None: # ignore step_seconds if datapoint_count is provided
+        # Ensure step_seconds is an integer, as required by the EDS API
+        step_seconds = int((TimeManager(dt_finish).as_unix()-TimeManager(dt_start).as_unix())/datapoint_count)
+    elif seconds_between_points is None and datapoint_count is None:
         step_seconds = helpers.nice_step(TimeManager(dt_finish).as_unix()-TimeManager(dt_start).as_unix()) # TimeManager(starttime).as_unix()
-    results = load_historic_data(session, iess_list, dt_start, dt_finish, step_seconds) 
+    elif seconds_between_points is not None and datapoint_count is None:
+        step_seconds = seconds_between_points
+    results = EdsClient.load_historic_data(session, iess_list, dt_start, dt_finish, step_seconds) 
     # results is a list of lists. Each inner list is a separate curve.
     if not results:
         return 
@@ -267,12 +282,15 @@ def trend(
     # Once the loop is done, you can call your show_static function
     # with the single, populated data_buffer.
 
-    if force_webplot or not force_matplotlib or not matplotlib_is_available_for_gui_plotting():
+    if force_matplotlib and not ph.matplotlib_is_available_for_gui_plotting():
+        typer.echo(f"force_matplotlib = {force_matplotlib}, but matplotlib is not available. Plotly, web-based plotting will be used.\n")
+    
+    if force_webplot or not force_matplotlib or not ph.matplotlib_is_available_for_gui_plotting():
         from pipeline import gui_plotly_static
         #from pipeline import gui_plotly_static_backup_06Oct25 as gui_plotly_static
         #gui_fastapi_plotly_live.run_gui(data_buffer)
         gui_plotly_static.show_static(data_buffer)
-    elif matplotlib_is_available_for_gui_plotting():
+    elif ph.matplotlib_is_available_for_gui_plotting():
         from pipeline import gui_mpl_live
         #gui_mpl_live.run_gui(data_buffer)
         gui_mpl_live.show_static(data_buffer)
@@ -305,7 +323,7 @@ def configure_credentials(
     """
     if textedit:
         typer.echo(F"Config filepath: {CONFIG_PATH}")
-        edit_textfile(CONFIG_PATH)
+        ph.edit_textfile(CONFIG_PATH)
         return
             
     typer.echo("")
@@ -322,11 +340,11 @@ def configure_credentials(
         typer.echo(f"Config file path: {CONFIG_PATH}", color=typer.colors.MAGENTA)   
 
     # Get a list of plant names from the user
-    num_plants = typer.prompt("How many EDS plants do you want to configure?", type=int, default=1)
-    
+    #num_plants = typer.prompt("How many EDS plants do you want to configure?", type=int, default=1)
+    num_plants = 1
     plant_names = []
     for i in range(num_plants):
-        plant_name = typer.prompt(f"Enter a unique name for Plant #{i+1} (e.g., 'Maxson' or 'Stiles')")
+        plant_name = typer.prompt(f"Enter a unique name for Plant (e.g., 'Maxson' or 'Stiles')")
         plant_names.append(plant_name)
 
     # Loop through each plant to configure its credentials
@@ -377,23 +395,23 @@ def setup_integration(
 
     if debug:
         # is_win_exe(debug=True) # inferred, not yet implemented
-        is_pipx(debug=True)
-        is_pyz(debug=True)
-        is_elf(debug=True)
+        ph.is_pipx(debug=True)
+        ph.is_pyz(debug=True)
+        ph.is_elf(debug=True)
         return
     
     if uninstall:
-        if on_windows():
+        if ph.on_windows():
             if typer.confirm("Are you sure you want to uninstall the registry context-menu item, the launcher BAT, and empty out the AppData folder?"):
                 cleanup_windows_integration()
-        elif on_termux():
+        elif ph.on_termux():
             cleanup_termux_integration()
         return
 
-    if on_windows():
+    if ph.on_windows():
         typer.echo("AppData will be set up explicity and a content menu item will be added to your Registry.")
         setup_windows_integration()
-    elif on_termux():
+    elif ph.on_termux():
         typer.echo("Scripts will now be added to the $HOME/.shortcuts/ directory for launching from the Termux Widget.")
         setup_termux_integration(force=upgrade)
         typer.echo("Update complete.")
@@ -480,11 +498,15 @@ def points_export(
     typer.echo(f"\nExport file saved to: \n{export_path}\n")
 
 @app.command()
-def help():
+def help(ctx: typer.Context):
     """
     Show help information.
     """
-    typer.echo(app.get_help())
+    if ctx.invoked_subcommand is None:
+        typer.echo(ctx.get_help())
+        raise typer.Exit()
+    
+    #typer.echo(app.get_help())
 
 if __name__ == "__main__":
     app()
